@@ -8,10 +8,8 @@ MODEL_FIELD_TO_GRAPHENE_TYPE = {
     'AutoField': graphene.ID,
     'BigAutoField': graphene.ID,
     'BigIntegerField': graphene.Int,
-    'BinaryField': graphene.String,
     'BooleanField': graphene.Boolean,
     'CharField': graphene.String,
-    'CommaSeparatedIntegerField': graphene.String,
     'DateField': graphene.Date,
     'DateTimeField': graphene.DateTime,
     'DecimalField': graphene.Decimal,
@@ -22,9 +20,7 @@ MODEL_FIELD_TO_GRAPHENE_TYPE = {
     'FloatField': graphene.Float,
     'ImageField': graphene_file_upload.scalars.Upload,
     'IntegerField': graphene.Int,
-    'IPAddressField': graphene.String,
     'GenericIPAddressField': graphene.String,
-    'NullBooleanField': graphene.Boolean,
     'PositiveIntegerField': graphene.Int,
     'PositiveSmallIntegerField': graphene.Int,
     'SlugField': graphene.String,
