@@ -24,6 +24,11 @@ def build_field_by_id_resolver(self):
             if 'field_by_id' in config['validators_by_operation']:
                 valid_operation=evaluate_result(config['validators_by_operation']['field_by_id'], info, result, **kwargs)
             if valid_operation:
+                callbacks=config.get('callbacks_by_operation').get('field_by_id')
+                if callbacks is not None:
+                    for callback in callbacks:
+                        if callable(callback):
+                            callback(info, result, **kwargs)
                 return result
         return None
     return field_resolver_function
@@ -74,12 +79,23 @@ def build_field_list_resolver(self):
         if valid:
             model=config.get('model')
             if pagination_length == 0:
-                return model.objects.filter(query_object)
+                result=model.objects.filter(query_object)
+                callbacks=config.get('callbacks_by_operation').get('list_field')
+                if callbacks is not None:
+                    for callback in callbacks:
+                        if callable(callback):
+                            callback(info, result, **kwargs)
+                return result
             else:
                 pagina=kwargs.get('page')
                 inicio=(pagina*pagination_length)-pagination_length
                 fin=inicio+pagination_length
                 items=model.objects.filter(query_object)[inicio:fin]
+                callbacks=config.get('callbacks_by_operation').get('list_field')
+                if callbacks is not None:
+                    for callback in callbacks:
+                        if callable(callback):
+                            callback(info, items, **kwargs)
                 if pagination_style=='infinite':
                     return items
                 else:
