@@ -25,6 +25,7 @@ from django.core.files.images import ImageFile
 from django.core.files.temp import tempfile
 import requests
 from .hasher import HashManager
+from moodle import Moodle
 
 class GroupManager:
     """ Manager for allow access to users by groups. """
@@ -93,7 +94,7 @@ class Manager:
     social_origin_facebook='FACEBOOK'
     social_origin_google='GOOGLE'
 
-    def __init__(self, user_model, session_key=None, use_social_session=False, rol_field_name='rol', login_id_field_name='uname', password_field_name='password', name_field_name="name", photo_field_name="photo", social_id_field=None, social_origin_field=None, active_field_name=None, session_expiration_time=12, groups={}, modify_permissions={}, security_key=None):
+    def __init__(self, user_model, session_key=None, use_social_session=False, rol_field_name='rol', login_id_field_name='uname', password_field_name='password', name_field_name="name", photo_field_name="photo", social_id_field=None, social_origin_field=None, active_field_name=None, session_expiration_time=12, groups={}, modify_permissions={}, security_key=None, moodle_urls=[], moodle_auth_field_name='username', moodle_id_field_name='email'):
         """Session Manager for a user_model
 
         Args:
@@ -112,9 +113,12 @@ class Manager:
             groups (dict, optional): Predefined access groups {"group_name":["rol_1", "rol_2", "rol_3"]}. Defaults to {}.
             modify_permissions (dict, optional): Predefined modify permissions {"rol_1":["rol_1", "rol_2", "rol_3"]}. Defaults to {}.
             security_key (str, optional): Secret used as secret for sign on jwt. Defaults to None for use django.conf.settings.SECRET_KEY.
+            moodle_urls (list, optional): List of dictionaries with moodle urls and token. Defaults to [].
+            moodle_auth_field_name (str, optional): Field name of moodle user model for authentication. Defaults to 'username'.
+            moodle_id_field_name (str, optional): Field name of moodle user model for identification. Defaults to 'email'.
         """
-        id_attribute=getattr(user_model, login_id_field_name)
-        if id_attribute.field.unique==False:
+        id_attribute=user_model._meta.get_field(login_id_field_name)
+        if id_attribute.unique==False:
             raise Exception('Field '+login_id_field_name+' must be unique')
         self.user_model=user_model
         self.session_key=session_key
@@ -131,6 +135,9 @@ class Manager:
         self.group_manager=GroupManager(user_model, rol_field_name, groups, modify_permissions)
         if security_key!=None:
             self._security_key=security_key
+        self.moodle_urls=moodle_urls
+        self.moodle_auth_field_name=moodle_auth_field_name
+        self.moodle_id_field_name=moodle_id_field_name
     
     def _generate_token(self, user_instance, expiration_time=0):
         """Generate jwt for user_instance
@@ -175,6 +182,17 @@ class Manager:
                     if self.user_model.objects.filter(id=payload['u_id']).exists():
                         user_instance=self.user_model.objects.get(id=payload['u_id'])
                         if self.group_manager.validar_acesso(user_instance, group_name):
+                            # import django_auditor_logs if exists
+                            if 'django_auditor_logs' in settings.INSTALLED_APPS:
+                                try:
+                                    from django_auditor_logs.metadata import MetadataManager
+                                    user_metadata={}
+                                    for field in user_instance._meta.get_fields():
+                                        if not field.is_relation:
+                                            user_metadata[field.name]=getattr(user_instance, field.name)
+                                    MetadataManager.set_user_metadata(user_metadata)
+                                except Exception as e:
+                                    print(e)
                             return True, user_instance, ErrorManager.get_error_by_code(NO_ERROR)
                         else:
                             return False, None, ErrorManager.get_error_by_code(ACCESS_DENIED)
@@ -187,6 +205,43 @@ class Manager:
         else:
             return False, None, ErrorManager.get_error_by_code(INVALID_TOKEN)
 
+    def _auth_with_moodle(self, login_id, password):
+        """Validate user with moodle
+
+        Args:
+            login_id (str): login id
+            password (str): password
+
+        Returns:
+            tuple:(status (bool), user_instance (UserObject))
+        """
+        for moodle_data in self.moodle_urls:
+            try:
+                response=requests.post(moodle_data['url']+'/login/token.php', data={'username':login_id, 'password':password, 'service':'moodle_mobile_app'})
+                if response.status_code==200:
+                    token=response.json()['token'] #validate only if token exists
+                    moodle = Moodle(moodle_data['url']+"/webservice/rest/server.php", moodle_data['token'])
+                    # get user info
+                    data_user=moodle('core_user_get_users_by_field', field=self.moodle_auth_field_name, values=[login_id])
+                    if len(data_user)>0:
+                        data_user=data_user[0]
+                        if self.user_model.objects.filter(**{self.login_id_field_name:data_user[self.moodle_id_field_name]}).exists():
+                            user_instance=self.user_model.objects.get(**{self.login_id_field_name:data_user[self.moodle_id_field_name]})
+                            return True, user_instance
+                        else:
+                            user_instance=self.user_model(**{self.social_id_field:id, self.name_field_name:data_user['fullname'], self.login_id_field_name:data_user[self.moodle_id_field_name]})
+                            if self.active_field_name!=None:
+                                setattr(user_instance, self.active_field_name, True)
+                            if 'profileimageurl' in data_user.keys() and data_user['profileimageurl']!='' and data_user['profileimageurl']!=None:
+                                photo=self.download_photo(data_user['profileimageurl'])
+                                fname=HashManager.getSHA1file(photo)
+                                getattr(user_instance, self.photo_field_name).save(f'{fname}.jpg', photo, save=True)
+                            user_instance.save()
+                            return True, user_instance
+            except:
+                pass
+        return False, None
+
     def start_session(self, login_id_value, password, permanent=False):
         """ Start session
 
@@ -199,6 +254,10 @@ class Manager:
         """
         if self.user_model!=None:
             try:
+                valid, user_instance=self._auth_with_moodle(login_id_value, password)
+                if valid:
+                    token=self._generate_token(user_instance, 0 if permanent else self.session_expiration_time)
+                    return True, user_instance, token, ErrorManager.get_error_by_code(NO_ERROR)
                 if self.user_model.objects.filter(**{self.login_id_field_name:login_id_value}).exists():
                     user_instance=self.user_model.objects.get(**{self.login_id_field_name:login_id_value})
                     if self.active_field_name==None or getattr(user_instance, self.active_field_name):
@@ -314,7 +373,7 @@ class Manager:
             return compare_object
         return actual_user_attr_getter_func
     
-    def build_access_level_validator(self, model_field='rol'):
+    def build_access_level_validator(self, model_field='rol', kwargs_field='rol'):
         """ Buuild a validator that validate if a model_instance.model_field is in the actual_user's access level """
         def access_level_validator(info, model_instance, **kwargs):
             valid, user_instance, error_message=self.validate_access(info.context, 'all')
@@ -325,7 +384,7 @@ class Manager:
                     compare_object=getattr(compare_object, sub_attr)
                     if compare_object==None and sub_attr!=sub_attrs[-1]:
                         return False
-                if compare_object in self.group_manager.get_modify_permissions(user_instance):
+                if compare_object in self.group_manager.get_modify_permissions(user_instance) and kwargs.get(kwargs_field, None) in self.group_manager.get_modify_permissions(user_instance):
                     return True
                 else:
                     return False
